@@ -1,6 +1,6 @@
 
 /*
-  $Id: iface.c,v 1.9 2002/09/24 12:43:34 ldv Exp $
+  $Id: iface.c,v 1.10 2002/12/23 16:10:55 ldv Exp $
 
   Copyright (C) 2001,2002  Dmitry V. Levin <ldv@altlinux.org>
 
@@ -129,6 +129,8 @@ execute_helper (int master_fd, const char *const argv[])
 	}
 }
 
+/* New interface. */
+
 int
 utempter_add_record (int master_fd, const char *hostname)
 {
@@ -170,3 +172,23 @@ utempter_set_helper (const char *pathname)
 {
 	utempter_pathname = pathname;
 }
+
+/* Old interface. */
+
+void
+addToUtmp (const char *pty, const char *hostname, int master_fd)
+{
+	utempter_add_record (master_fd, hostname);
+}
+
+void
+removeFromUtmp (void)
+{
+	utempter_remove_added_record ();
+}
+
+void
+removeLineFromUtmp (const char *pty, int master_fd)
+{
+	utempter_remove_record (master_fd);
+}
